==> julynter-0.3.3-py3-none-any.whl: package/lib/linterlab/view/statusrenderer.js <==
import * as React from 'react';
import { showDialog, Dialog } from '@jupyterlab/apputils';
export class StatusRenderer extends React.Component {
    chooseMessageIcon() {
        try {
            if (!this.props.connectedOnce) {
                return [
                    'Julynter did not connect to a notebook',
                    'julynter-never-connected-icon julynter-icon',
                ];
            }
            if (!this.props.connectedNow) {
                return [
                    'Julynter is not connected to a notebook',
                    'julynter-disconnected-icon julynter-icon',
                ];
            }
            if (!this.props.hasKernel) {
                return ['Kernel not found', 'julynter-kernel-off-icon julynter-icon'];
            }
            return ['Kernel connected', 'julynter-kernel-on-icon julynter-icon'];
        }
        catch (error) {
            throw this.props.errorHandler.report(error, 'StatusRenderer:chooseMessageIcon', []);
        }
    }
    clickError() {
        try {
            const text = this.props.errorHandler.errorStack.join('\n\n');
            showDialog({
                title: 'List of errors',
                body: (React.createElement("div", null,
                    React.createElement("div", null, "Please, submit the following log as a Bug report to"),
                    React.createElement("div", null,
                        React.createElement("a", { target: "_blank", href: "https://github.com/dew-uff/julynter/issues" }, "https://github.com/dew-uff/julynter/issues")),
                    React.createElement("textarea", { className: "julynter-error-text", value: text }),
                    React.createElement("div", null, "* Check the Browser console as well."))),
                buttons: [
                    Dialog.cancelButton({ label: 'Dismiss' }),
                    Dialog.okButton({ label: 'Clear' }),
                ],
            }).then((result) => {
                Promise.resolve(result.button.accept).then((ok) => {
                    try {
                        if (ok) {
                            this.props.errorHandler.clear();
                            this.forceUpdate();
                        }
                    }
                    catch (error) {
                        throw this.props.errorHandler.report(error, 'StatusRenderer:clickError.ok', [ok]);
                    }
                });
            });
        }
        catch (error) {
            throw this.props.errorHandler.report(error, 'StatusRenderer:clickError', []);
        }
    }
    render() {
        try {
            const [message, icon] = this.chooseMessageIcon();
            let exp = null;
            let error = null;
            if (this.props.experiment) {
                exp = React.createElement("span", { title: "Experiment is Active" }, "e");
            }
            if (this.props.errorHandler.errorStack.length > 0) {
                error = (React.createElement("span", { className: "julynter-error-display", onClick: this.clickError.bind(this), title: "Click to see errors" }, "[Error]"));
            }
            return (React.createElement("div", { className: "jp-Julynter-kernel" },
                error,
                exp,
                React.createElement("div", { role: "text", "aria-label": message, title: message, className: icon })));
        }
        catch (error) {
            throw this.props.errorHandler.report(error, 'StatusRenderer:render', []);
        }
    }
}

==> julynter-0.4.1-py3-none-any.whl: package/lib/linterlab/view/statusrenderer.js <==
import * as React from 'react';
import { showDialog, Dialog } from '@jupyterlab/apputils';
import { neverconnectedIcon, disconnectedIcon, kerneloffIcon, kernelonIcon, } from '../../iconimports';
export class StatusRenderer extends React.Component {
    chooseMessageIcon() {
        try {
            if (!this.props.connectedOnce) {
                return ['Julynter did not connect to a notebook', neverconnectedIcon];
            }
            if (!this.props.connectedNow) {
                return ['Julynter is not connected to a notebook', disconnectedIcon];
            }
            if (!this.props.hasKernel) {
                return ['Kernel not found', kerneloffIcon];
            }
            return ['Kernel connected', kernelonIcon];
        }
        catch (error) {
            throw this.props.errorHandler.report(error, 'StatusRenderer:chooseMessageIcon', []);
        }
    }
    clickError() {
        try {
            const text = this.props.errorHandler.errorStack.join('\n\n');
            showDialog({
                title: 'List of errors',
                body: (React.createElement("div", null,
                    React.createElement("div", null, "Please, submit the following log as a Bug report to"),
                    React.createElement("div", null,
                        React.createElement("a", { target: "_blank", rel: "noreferrer", href: "https://github.com/dew-uff/julynter/issues" }, "https://github.com/dew-uff/julynter/issues")),
                    React.createElement("textarea", { className: "julynter-error-text", value: text }),
                    React.createElement("div", null, "* Check the Browser console as well."))),
                buttons: [
                    Dialog.cancelButton({ label: 'Dismiss' }),
                    Dialog.okButton({ label: 'Clear' }),
                ],
            }).then((result) => {
                Promise.resolve(result.button.accept).then((ok) => {
                    try {
                        if (ok) {
                            this.props.errorHandler.clear();
                            this.forceUpdate();
                        }
                    }
                    catch (error) {
                        throw this.props.errorHandler.report(error, 'StatusRenderer:clickError.ok', [ok]);
                    }
                });
            });
        }
        catch (error) {
            throw this.props.errorHandler.report(error, 'StatusRenderer:clickError', []);
        }
    }
    render() {
        try {
            const [message, icon] = this.chooseMessageIcon();
            let exp = null;
            let error = null;
            if (this.props.experiment) {
                exp = React.createElement("span", { title: "Experiment is Active" }, "e");
            }
            if (this.props.errorHandler.errorStack.length > 0) {
                error = (React.createElement("span", { className: "julynter-error-display", onClick: this.clickError.bind(this), title: "Click to see errors" }, "[Error]"));
            }
            return (React.createElement("div", { className: "jp-Julynter-kernel", title: message },
                error,
                exp,
                React.createElement(icon.react, { elementSize: "normal", className: "julynter-icon", elementPosition: "center" })));
        }
        catch (error) {
            throw this.props.errorHandler.report(error, 'StatusRenderer:render', []);
        }
    }
}
